<?php
$CONFIG = array (
  'passwordsalt' => '2OMTFYv86AaGuES/RQfFEW0voZqacr',
  'secret' => 'ENdYBknYh8qJMXDXrJJ+8T8hI02YM+C9apCbNN3onkDYmFkG',
  'trusted_domains' => 
  array (
    0 => 'localhost',
  ),
  'datadirectory' => '/var/www/nextcloud-data',
  'dbtype' => 'mysql',
  'version' => '26.0.0.11',
  'overwrite.cli.url' => 'http://localhost',
  'dbname' => 'nextcloud',
  'dbhost' => 'localhost',
  'dbport' => '',
  'dbtableprefix' => 'oc_',
  'mysql.utf8mb4' => true,
  'dbuser' => 'nextcloud',
  'dbpassword' => '5b506783216a09366aafcbc1e070350d',
  'installed' => true,
  'instanceid' => 'ocm6idu29tg8',
  'memcache.local' => '\OC\Memcache\Redis',
  'redis' => array(
      'host' => '/var/run/redis/redis.sock',
      'port' => 0,
      'timeout' => 0.0
  ),
  'filelocking.enabled' => true,
  'memcache.locking' => '\OC\Memcache\Redis',
);
